@@ -4,7 +4,7 @@ use warnings;
 use 5.006;
 
 package HTTP::BrowserDetect;
-$HTTP::BrowserDetect::VERSION = '3.10';
+$HTTP::BrowserDetect::VERSION = '3.11';
 use vars qw(@ALL_TESTS);
 
 # Operating Systems
@@ -59,7 +59,7 @@ our @GAMING_TESTS = qw(
 # Device related tests
 our @DEVICE_TESTS = qw(
     android audrey blackberry dsi iopener ipad
-    iphone ipod kindle n3ds palm ps3 psp wap webos
+    iphone ipod kindle kindlefire n3ds palm ps3 psp wap webos
     mobile tablet
 );
 
@@ -2062,6 +2062,7 @@ sub _init_device {
             my $model = $1;
             if ( $model =~ m{^KF} ) {
                 $device_string = "Android tablet (Kindle Fire)";
+                $device_tests->{kindlefire} = 1;
             }
             else {
                 $device_string = "Android tablet ($model)";
@@ -2631,7 +2632,7 @@ HTTP::BrowserDetect - Determine Web browser, version, and platform from an HTTP
 
 =head1 VERSION
 
-version 3.10
+version 3.11
 
 =head1 SYNOPSIS
 
@@ -3083,6 +3084,8 @@ The following methods are available, each returning a true or false value.
 
 =head3 kindle
 
+=head3 kindlefire
+
 =head3 n3ds
 
 =head3 obigo
